@@ -7,7 +7,7 @@ import GHC.Exts
 import GHC.Types
 
 class BoxIt (a :: TYPE 'WordRep) where
-    type Boxed a :: *
+    type Boxed a :: Type
     boxed :: a -> Boxed a
 
 instance BoxIt Char# where
