@@ -17,13 +17,12 @@ testMe (HsOverLabel xol s m_ip) = _
 testMe (HsIPVar xv hin) = _
 testMe (HsOverLit xole hol) = _
 testMe (HsLit xle hl) = _
-testMe (HsLam xl mg) = _
-testMe (HsLamCase xlc lc_variant mg) = _
+testMe (HsLam xlc lc_variant mg) = _
 testMe (HsApp xa gl gl') = _
-testMe (HsAppType xate gl at hwcb) = _
+testMe (HsAppType xate gl hwcb) = _
 testMe (OpApp xoa gl gl' gl2) = _
 testMe (NegApp xna gl se) = _
-testMe (HsPar xp gl ab ac) = _
+testMe (HsPar xp ab) = _
 testMe (SectionL xsl gl gl') = _
 testMe (SectionR xsr gl gl') = _
 testMe (ExplicitTuple xet gls box) = _
@@ -31,7 +30,7 @@ testMe (ExplicitSum xes n i gl) = _
 testMe (HsCase xc gl mg) = _
 testMe (HsIf xi m_se gl gl' ) = _
 testMe (HsMultiIf xmi gls) = _
-testMe (HsLet xl tkLet gl tkIn gl') = _
+testMe (HsLet xl gl gl') = _
 testMe (HsDo xd hsc gl) = _
 testMe (ExplicitList xel m_se) = _
 testMe (RecordCon xrc gl hrf) = _
