@@ -11,4 +11,4 @@ type F1 :: forall k -> Type
 type family F1 k :: Type
 
 type F2 :: forall x. forall k -> x
-type F2 = F1
+type F2 k = F1 k
